/**
* Copyright (c) 2006-2009 Nokia Corporation and/or its subsidiary(-ies).
* All rights reserved.
* This component and the accompanying materials are made available
* under the terms of "Eclipse Public License v1.0"
* which accompanies this distribution, and is available
* at the URL "http://www.eclipse.org/legal/epl-v10.html".
*
* Initial Contributors:
* Nokia Corporation - initial contribution.
*
* Contributors:
*
* Description:
*
*/



/**
 @file commsdatCorruptionTests.h
*/
#if (!defined __COMMSDAT_CORRUPTION_TESTS_H__)
#define __COMMSDAT_CORRUPTION_TESTS_H__

_LIT(KCommsdat300Step,"commsdat300Step");
class CCommsdat300Step : public CTe_commsdatSuiteStepBase
	{
public:
	CCommsdat300Step();
	~CCommsdat300Step();
	virtual TVerdict doTestStepL();
private:
	};	
	
	
_LIT(KCommsdat301Step,"commsdat301Step");
class CCommsdat301Step : public CTe_commsdatSuiteStepBase
	{
public:
	CCommsdat301Step();
	~CCommsdat301Step();
	virtual TVerdict doTestStepL();
private:
	};	
	
	
_LIT(KCommsdat302Step,"commsdat302Step");
class CCommsdat302Step : public CTe_commsdatSuiteStepBase
	{
public:
	CCommsdat302Step();
	~CCommsdat302Step();
	virtual TVerdict doTestStepL();
private:
	};	
	
	
_LIT(KCommsdat303Step,"commsdat303Step");
class CCommsdat303Step : public CTe_commsdatSuiteStepBase
	{
public:
	CCommsdat303Step();
	~CCommsdat303Step();
	virtual TVerdict doTestStepL();
private:
	};	
	
_LIT(KCommsdat304Step,"commsdat304Step");
class CCommsdat304Step : public CTe_commsdatSuiteStepBase
	{
public:
	CCommsdat304Step();
	~CCommsdat304Step();
	virtual TVerdict doTestStepL();
private:
	};	
	
_LIT(KCommsdat305Step,"commsdat305Step");
class CCommsdat305Step : public CTe_commsdatSuiteStepBase
	{
public:
	CCommsdat305Step();
	~CCommsdat305Step();
	virtual TVerdict doTestStepL();
private:
	};	

_LIT(KCommsdat306Step,"commsdat306Step");
class CCommsdat306Step : public CTe_commsdatSuiteStepBase
	{
public:
	CCommsdat306Step();
	~CCommsdat306Step();
	virtual TVerdict doTestStepL();
private:
	};	
	
#endif //__COMMSDAT_CORRUPTION_TESTS_H__
